//
//  ActionButton.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 13/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import Foundation
import UIKit

class ActionButton: UIButton {
    public var roundRectCornerRadius: CGFloat = 8 {
        didSet {
            self.setNeedsLayout()
        }
    }
    
    @IBInspectable public var roundBackgroundColor: UIColor = UIColor.orange {
        didSet {
            self.setNeedsLayout()
        }
    }
    
    @IBInspectable public var textColor: UIColor = UIColor.white {
        didSet {
            self.setNeedsLayout()
        }
    }
    
    override public func layoutSubviews() {
        super.layoutSubviews()
        layoutRoundRectLayer()
    }
    
    private var roundRectLayer: CAShapeLayer?
    
    private func layoutRoundRectLayer() {
        
        frame.size = CGSize(width: frame.width, height: 40)
        
        if let existingLayer = roundRectLayer {
            existingLayer.removeFromSuperlayer()
        }
        
        let shapeLayer = CAShapeLayer()
        shapeLayer.path = UIBezierPath(roundedRect: self.bounds, cornerRadius: roundRectCornerRadius).cgPath
        shapeLayer.fillColor = roundBackgroundColor.cgColor
        
        self.layer.insertSublayer(shapeLayer, at: 0)
        self.roundRectLayer = shapeLayer
        self.tintColor = textColor
    }
}
