//
//  Book.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 15/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import Foundation
import ObjectMapper

class Book: Mappable {
    
    enum Role: String {
        case producer = "producer"
        case consumer = "consumer"
    }
    
    enum Status: String {
        case pending  = "pending"
        case active   = "active"
        case finished = "finished"
    }
    
    static let Steps = [
        "Pending confirmation".localize(),
        "Pending deliver".localize(),
        "Pending return".localize(),
        "Finished".localize()
    ]
    
    var id: String          = ""
    var startAt: String     = ""
    var endAt: String       = ""
    var step: Int           = 0
    var product: String     = ""
    var user: String       	= ""
    var hasReview: Bool     = false
    
    let formatter: DateFormatter = DateFormatter()
    
    init(product: Product, startAt: Date, endAt: Date) {
        formatter.dateFormat = "dd/MM/yyyy"
        formatter.timeZone = Calendar.current.timeZone
        formatter.locale = Calendar.current.locale
        
        self.id         = UUID().uuidString
        self.startAt    = formatter.string(from: startAt)
        self.endAt      = formatter.string(from: endAt)
        self.user       = UserNetwork.isLogged() ? UserNetwork.currentUser().uid : ""
        self.product    = product.id
    }
    
    public required init?(map: Map) {
    }
    
    func mapping(map: Map) {
        self.id         <- map["id"]
        self.startAt    <- map["startAt"]
        self.endAt      <- map["endAt"]
        self.user       <- map["user"]
        self.product    <- map["product"]
        self.step       <- map["step"]
        self.hasReview  <- map["hasReview"]
    }
    
    static func mapDictionary(json: [String : [String : Any]]) -> [Book] {
        let dictionary = Mapper<Book>().mapDictionary(JSON: json)
        
        var books: [Book] = []
        for book in dictionary!.values {
            books.append(book)
        }
        
        return books
    }
    
    func statusLabel() -> String {
        return Book.Steps[self.step]
    }
    
    func isFinished() -> Bool {
        return self.step == 3
    }
}

