//
//  BookDetailViewController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 12/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit

class BookDetailViewController: MainViewController {
    @IBOutlet weak var actionButton: ActionButton!
    @IBOutlet weak var scrollView: UIScrollView!
    @IBOutlet weak var stackView: UIStackView!
    
    @IBOutlet weak var reservationStepView: TimeLineRowView!
    @IBOutlet weak var confirmationStepView: TimeLineRowView!
    @IBOutlet weak var deliverStepView: TimeLineRowView!
    @IBOutlet weak var finishStepView: TimeLineRowView!
    
    var book: Book
    var product: Product?
    
    init(book: Book) {
        self.book = book
        super.init(nibName: "BookDetailViewController", bundle: nil)
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func viewDidLoad() {
        scrollView.isScrollEnabled = scrollView.frame.height > scrollView.frame.height
        
        ProductNetwork.get(status: "published", productId: book.product) { (product, error) in
            self.product = product
        }
        
        actionButton.isHidden = book.user == UserNetwork.currentUser().uid || book.isFinished()
        
        switch book.step {
        case 1:
            actionButton.setTitle("Confirm delivery".localize(), for: .normal)
        case 2:
            actionButton.setTitle("Confirm return".localize(), for: .normal)
        default:
            actionButton.setTitle("Confirm".localize(), for: .normal)
        }
        
        if book.isFinished() && !book.hasReview {
            actionButton.isHidden = false
            actionButton.addTarget(self, action: #selector(goToReview), for: .touchUpInside)
            actionButton.setTitle("Share a review".localize(), for: .normal)
        }
        
        navigationItem.rightBarButtonItem = UIBarButtonItem(
            title: "Go to chat".localize(),
            style: .plain,
            target: self,
            action: #selector(goToChat)
        )
    }
    
    func goToReview() {
        let vc = NewReviewViewController(book: book)
        vc.hidesBottomBarWhenPushed = true
        navigationController?.pushViewController(vc, animated: true)
    }
    
    @IBAction func onTapActionButton(_ sender: Any) {
        let status = book.step == 0 ? Book.Status.pending : Book.Status.active
        
        BookNetwork.updateBookStep(book: book, status: status) { (book, error) in
            if let book = book {
                self.book = book
                self.reloadView()
            }
        }
    }

    
    func goToChat() {
        NotificationCenter.default.post(
            name: NSNotification.Name(rawValue: Constant.Event.openChat),
            object: nil,
            userInfo: ["book": book]
        )
    }
    
    override func viewWillAppear(_ animated: Bool) {
        reloadView()
    }
    
    func reloadView() {
        switch book.step {
        case 1:
            reservationStepView.sectionsActivated   = 2
            confirmationStepView.sectionsActivated  = 1
            deliverStepView.sectionsActivated       = 0
            finishStepView.sectionsActivated        = 0
            
        case 2:
            reservationStepView.sectionsActivated   = 2
            confirmationStepView.sectionsActivated  = 2
            deliverStepView.sectionsActivated       = 1
            finishStepView.sectionsActivated        = 0
        case 3:
            reservationStepView.sectionsActivated   = 2
            confirmationStepView.sectionsActivated  = 2
            deliverStepView.sectionsActivated       = 2
            finishStepView.sectionsActivated        = 1
        default:
            reservationStepView.sectionsActivated   = 1
            confirmationStepView.sectionsActivated  = 0
            deliverStepView.sectionsActivated       = 0
            finishStepView.sectionsActivated        = 0
        }

    }
}
