//
//  BookListViewController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 12/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit

class BookListViewController: MainViewController {

    @IBOutlet weak var segmentedControl: UISegmentedControl!
    @IBOutlet weak var tableView: UITableView!
    
    var sections: Array<String> = []
    var books: [[Book]] = [[], [], []]
    var currentRole: Book.Role = Book.Role.consumer
    var refreshControl: UIRefreshControl!
    var sectionsLoaded = 0
    var activeBooks: [Book] = []
    var pendingBooks: [Book]  = []
    var finishedBooks: [Book]  = []
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.onTableViewDidLoad()
        segmentedControl.tintColor = UIColor.blue
        tableView.contentInset = UIEdgeInsets(top: 60, left: 0, bottom: 0, right: 0)
        
    }
    
    @IBAction func onChangeSegmentControl(_ sender: Any) {
        currentRole = segmentedControl.selectedSegmentIndex == 0
            ? Book.Role.consumer
            : Book.Role.producer
        
        refreshData()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        navigationController?.hide()
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        navigationController?.setTranslucentBar()
        navigationItem.backBarButtonItem = UIBarButtonItem(title: "", style: .plain, target: nil, action: nil)
    }
}

extension BookListViewController: UITableViewDataSource, UITableViewDelegate {
    func onTableViewDidLoad() {
        tableView.delegate = self
        tableView.dataSource = self
        tableView.separatorStyle = .none
        tableView.register(UINib(nibName: "BookTableViewCell", bundle: nil), forCellReuseIdentifier: "cell")
        refreshControl = UIRefreshControl()
        refreshControl.addTarget(self, action: #selector(refreshData), for: .valueChanged)
        tableView.refreshControl = refreshControl
        
        if UserNetwork.isLogged() {
            refreshData()
        }
    }
    
    func refreshData() -> Void {
        refreshControl.beginRefreshing()
        books = []
        sectionsLoaded = 0
        
        BookNetwork.getUserBooks(role: currentRole, status: .pending) { (books, error) in
            self.pendingBooks = books
            self.sectionsLoaded = self.sectionsLoaded + 1
            self.reloadData()
        }
        
        BookNetwork.getUserBooks(role: currentRole, status: .active) { (books, error) in
            self.activeBooks = books
            self.sectionsLoaded = self.sectionsLoaded + 1
            self.reloadData()
        }
        
        BookNetwork.getUserBooks(role: currentRole, status: .finished) { (books, error) in
            self.finishedBooks = books
            self.sectionsLoaded = self.sectionsLoaded + 1
            self.reloadData()
        }
    }
    
    func reloadData() {
        guard sectionsLoaded == 3 else {
            return
        }
        
        refreshControl.endRefreshing()
        
        books = []
        sections = []
        
        if (!pendingBooks.isEmpty) {
            books.append(pendingBooks)
            sections.append("Pendings".localize())
        }
        if (!activeBooks.isEmpty) {
            books.append(activeBooks)
            sections.append("Actives".localize())
        }
        if (!finishedBooks.isEmpty) {
            books.append(finishedBooks)
            sections.append("Finisheds".localize())
        }
        
        tableView.reloadData()
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        let book = books[indexPath.section][indexPath.row]
        let vc = BookDetailViewController(book: book)
        navigationController?.pushViewController(vc, animated: true)
    }
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 0
            + (pendingBooks.count > 0).toInteger()
            + (activeBooks.count > 0).toInteger()
            + (finishedBooks.count > 0).toInteger()
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return books[section].count
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return 95
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "cell", for: indexPath) as! BookTableViewCell
        
        let book = self.books[indexPath.section][indexPath.row]
        cell.loadData(book: book, callback: {
            tableView.reloadRows(at: [indexPath], with: .fade)
        })
        
        return cell;
    }
    
    func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        return sections[section]
    }
}
