//
//  BookNetwork.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 15/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import FirebaseDatabase
import ObjectMapper

class BookNetwork {
    static func get(status: String, bookId: String, _ completion: @escaping (_ : Book?, _ : Error? ) -> Void) {
        let path = "/books/\(status)/\(bookId)"
        
        FIRDatabase
            .database()
            .reference()
            .child(path)
            .observeSingleEvent(of: .value) { (snapshot: FIRDataSnapshot) in
                guard let json = snapshot.value as? [String: Any] else {
                    completion(nil, nil)
                    return
                }
                guard let book = Mapper<Book>().map(JSON: json) else {
                    completion(nil, nil)
                    return
                }
                
                completion(book, nil)
        }
    }
    
    static func createBook(book: Book, _ completion: @escaping (_ : Book?, _ : Error? ) -> Void) {
        FIRDatabase
            .database()
            .reference()
            .child(Constant.Firebase.Snapshot.books)
            .child(book.id)
            .setValue(book.toJSON())
        
        completion(book, nil)
    }
    
    static func getUserBooks(role: Book.Role, status: Book.Status, _ completion: @escaping (_ : [Book], _ : Error? ) -> Void) {
        let path = "/users/\(UserNetwork.currentUser().uid)/books/\(role)/\(status)"
        let reference = FIRDatabase.database().reference()
        
        reference.child(path).observeSingleEvent(of: .value) { (snapshot: FIRDataSnapshot) in
            guard let snapshots = snapshot.value as? [String : Bool] else {
                return completion([], nil)
            }
            
            var books = [Book]()
            for (bookId, _) in snapshots {
                reference.child("books/\(status)/\(bookId)").observeSingleEvent(of: .value) { (snapshot: FIRDataSnapshot) in
                    guard let json = snapshot.value as? [String: Any] else {
                        return
                    }
                    guard let book = Mapper<Book>().map(JSON: json) else {
                        return
                    }
                    
                    books.append(book)
                    
                    if books.count == snapshots.count {
                        return completion(books, nil)
                    }
                }
            }
        }
    }
    
    static func updateBookStep(book: Book, status: Book.Status, _ completion: @escaping (_ : Book?, _ : Error? ) -> Void) {
        let path = "/books/\(status)/\(book.id)/step"
        
        book.step = book.step + 1
        FIRDatabase
            .database()
            .reference()
            .child(path)
            .setValue(book.step)
        
        completion(book, nil)
    }
}
