//
//  LoginViewController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 12/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit

class LoginViewController: MainViewController {
        
    var emailTextField: UITextField!
    var passwordTextField: UITextField!
    
    @IBOutlet weak var titleLabel: UILabel!
    @IBOutlet weak var subTitleLabel: UILabel!
    @IBOutlet weak var tableView: UITableView!
    @IBOutlet weak var loginButton: ActionButton!
    @IBOutlet weak var signUpButton: UIButton!
    @IBOutlet weak var rememberPasswordButton: UIButton!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        tableViewDidLoad()
        
        titleLabel.text = "LoginTitle".localize()
        subTitleLabel.text = "LoginSubTitle".localize()
        loginButton.setTitle("Enter".localize(), for: .normal)
        signUpButton.setTitle("Create account".localize(), for: .normal)
        rememberPasswordButton.setTitle("Remember password".localize(), for: .normal)
    }
    
    override func viewWillAppear(_ animated: Bool) {
        navigationController?.setNavigationBarHidden(true, animated: false)
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        navigationController?.setTranslucentBar()
        navigationController?.navigationBar.tintColor = UIColor.darkGray
        navigationItem.backBarButtonItem = UIBarButtonItem(title: "", style: .plain, target: nil, action: nil)
        
    }
    
    @IBAction func onTapCloseButton(_ sender: UIButton) {
        dismiss(animated: true, completion: nil)
    }
    
    @IBAction func onTapLoginButton(_ sender: UIButton) {
        let email = self.getCell(row: 0).inputTextField.text
        let password = self.getCell(row: 1).inputTextField.text
        
        guard email != nil && password != nil else {
            return
        }
        
        UserNetwork.login(email: email!, password: password!) { (user, error) in
            if let error = error {
                print(error.description)
                // TODO: Show error to user
            }
            
            if user != nil {
                self.dismiss(animated: true, completion: nil)
            }
        }
    }
    
    @IBAction func onTapSignUpButton(_ sender: UIButton) {
        navigationController?.pushViewController(SignUpViewController(), animated: true)
    }
    
    @IBAction func onTapRememberPasswordButton(_ sender: UIButton) {
    }
}


extension LoginViewController: UITableViewDelegate, UITableViewDataSource {
    
    func tableViewDidLoad() {
        tableView.delegate = self
        tableView.dataSource = self
        tableView.separatorStyle = .none
        tableView.allowsSelection = false
        tableView.keyboardDismissMode = .interactive
        
        tableView.register(UINib(nibName: "InputTextTableViewCell", bundle: nil), forCellReuseIdentifier: "cell")
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return 100
    }
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 2
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "cell", for: indexPath) as! InputTextTableViewCell
        cell.inputTextField.delegate = self
        
        switch indexPath.row {
        case 0:
            cell.inputTextField.placeholder = "Email".localize()
            cell.inputTextField.keyboardType = .emailAddress
            cell.imageView?.image = UIImage(named: "ic_email")
            emailTextField = cell.inputTextField
        default:
            cell.inputTextField.placeholder = "Password".localize()
            cell.inputTextField.isSecureTextEntry = true
            cell.imageView?.image = UIImage(named: "ic_locked")
            passwordTextField = cell.inputTextField
        }

        return cell
    }
    
    func getCell(row: Int) -> InputTextTableViewCell {
        return tableView.cellForRow(at: IndexPath(row: row, section: 0)) as! InputTextTableViewCell
    }
}

extension LoginViewController: UITextFieldDelegate {
    
    func textFieldDidEndEditing(_ textField: UITextField) {
        loginButton.isUserInteractionEnabled = true
            && !(emailTextField.text?.isEmpty)!
            && !(passwordTextField.text?.isEmpty)!
    }
    
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        if textField === self.emailTextField {
            passwordTextField.becomeFirstResponder()
        } else {
            view.endEditing(true)
        }
        
        return true
    }
}
