//
//  MainLocationManagerDelegateViewController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 21/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit
import CoreLocation

protocol LocationManagerDelegate {
    func onReceiveCoordinates(latitude: Double, longitude: Double)
    func onFailLocation(error: Error)
}

class MainLocationManager: NSObject, CLLocationManagerDelegate {
    
    var locationManager: CLLocationManager?
    private let delegate: LocationManagerDelegate
    
    init(delegate: LocationManagerDelegate) {
        self.delegate = delegate
        self.locationManager = CLLocationManager()
    }
    
    func determineMyCurrentLocation() {
        locationManager?.delegate = self
        locationManager?.desiredAccuracy = kCLLocationAccuracyBest
        locationManager?.requestWhenInUseAuthorization()
        
        if CLLocationManager.locationServicesEnabled() {
            locationManager?.startUpdatingLocation()
        }
    }
    
    func locationManager(_ manager: CLLocationManager, didUpdateLocations locations: [CLLocation]) {
        let userLocation:CLLocation = locations[0] as CLLocation
        let latitude = Double(userLocation.coordinate.latitude)
        let longitude = Double(userLocation.coordinate.longitude)
        
        manager.stopUpdatingLocation()
        delegate.onReceiveCoordinates(latitude: latitude, longitude: longitude)
    }
    
    func locationManager(_ manager: CLLocationManager, didFailWithError error: Error)
    {
        delegate.onFailLocation(error: error)
    }
}
