//
//  MainTabBarController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 12/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit

class MainTabBarController: UITabBarController, UITabBarControllerDelegate {
    
    var currentTabIndex: Int = 0
    
    override func viewDidLoad() {
        super.viewDidLoad()
        delegate = self
        tabBar.tintColor = UIColor.blue
        tabBar.isTranslucent = false
        
        viewControllers = [
            createExploreTab(),
            createBooksTab(),
            createAddTab(),
            createMessagesTab(),
            createProfileTab()
        ]
        
        selectedIndex = 0
        
        NotificationCenter.default.addObserver(
            self,
            selector: #selector(onBookCreated(_:)),
            name: NSNotification.Name(rawValue: Constant.Event.openChat),
            object: nil
        )
    }
    
    func tabBarController(_ tabBarController: UITabBarController, didSelect viewController: UIViewController) {
        if selectedIndex == 2 {
            selectedIndex = currentTabIndex
            let vc = ProtectedViewController(NewProductViewController(nibName: "NewProductViewController", bundle: nil), isModal: true)
            present(vc, animated: true, completion: nil)            
            return
        }
        
        currentTabIndex = selectedIndex
    }

    
    func onBookCreated(_ notification: NSNotification) {
        let book = notification.userInfo?["book"] as! Book
        
        selectedIndex = 3
        let navigationController = viewControllers![3] as! MainNavigationController
        let vc = RoomDetailViewController(book: book)
        vc.hidesBottomBarWhenPushed = true
        navigationController.pushViewController(vc, animated: true)
    }
    
    func createExploreTab() -> UIViewController {
        let navigationController = MainNavigationController()
        let vc = ProductListViewController()
        let tabItem = UITabBarItem(
            title: "Explore".localize(),
            image: UIImage(named: "ic_tab_explore"),
            selectedImage: UIImage(named: "ic_tab_explore")
        )
        
        navigationController.viewControllers = [vc]
        vc.tabBarItem = tabItem
        
        return navigationController
    }
    
    func createBooksTab() -> UIViewController {
        let navigationController = MainNavigationController()
        let vc = ProtectedViewController(BookListViewController())
        let tabItem = UITabBarItem(
            title: "Books".localize(),
            image: UIImage(named: "ic_calendar"),
            selectedImage:  UIImage(named: "ic_calendar")
            
        )
        
        navigationController.viewControllers = [vc]
        vc.tabBarItem = tabItem
        
        return navigationController
    }
    
    func createMessagesTab() -> UIViewController {
        let navigationController = MainNavigationController()
        let vc = ProtectedViewController(RoomListViewController())
        let tabItem = UITabBarItem(
            title: "Messages".localize(),
            image: UIImage(named: "ic_tab_messages"),
            selectedImage: UIImage(named: "ic_tab_messages")
        )
        
        navigationController.viewControllers = [vc]
        vc.tabBarItem = tabItem
        
        return navigationController
    }
    
    func createProfileTab() -> UIViewController {
        let navigationController = MainNavigationController()
        let vc = ProtectedViewController(ProfileViewController())
        let tabItem = UITabBarItem(
            title: "Profile".localize(),
            image: UIImage(named: "ic_settings"),
            selectedImage: UIImage(named: "ic_settings")
        )
        
        navigationController.viewControllers = [vc]
        vc.tabBarItem = tabItem
        
        return navigationController
    }
    
    func createAddTab() -> UIViewController {
        let vc = UIViewController()
        
        let tabItem = UITabBarItem(
            title: "Publish".localize(),
            image: UIImage(named: "ic_tab_main"),
            selectedImage: UIImage(named: "ic_tab_main")
        )
        
        vc.tabBarItem = tabItem
        
        return vc
    }
}
