//
//  NewProductViewController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 13/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit
import SkyFloatingLabelTextField

class NewProductViewController: MainViewController, UINavigationControllerDelegate {
    struct Row {
        static let title = 0
        static let category = 1
        static let price = 2
        static let description = 3
    }
    
    @IBOutlet weak var tableView: UITableView!
    @IBOutlet weak var collectionView: UICollectionView!
    @IBOutlet weak var actionButton: ActionButton!
    
    var images: [UIImage] = []
    let picker = UIImagePickerController()
    var selectedPhotoButton: UIButton!
    var currentTextField: UITextField?
    
    var titleTextField: SkyFloatingLabelTextField!
    var categoryTextField: SkyFloatingLabelTextField!
    var priceTextField: SkyFloatingLabelTextField!
    var descriptionTextField: SkyFloatingLabelTextField!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.tableViewExtensionDidLoad()
        self.uiImagePickerExtensionDidLoad()
        collectionView.register(
            UINib(nibName: "PhotosCollectionViewCell", bundle: nil),
            forCellWithReuseIdentifier: "PhotosCollectionViewCell"
        )
        
        collectionView.delegate = self
        collectionView.dataSource = self
        collectionView.reloadData()
        
        NotificationCenter.default.addObserver(self, selector: #selector(keyboardWillShow), name: NSNotification.Name.UIKeyboardWillShow, object: nil)
        NotificationCenter.default.addObserver(self, selector: #selector(keyboardWillHide), name: NSNotification.Name.UIKeyboardWillHide, object: nil)
    }
    
    func keyboardWillShow(notification: NSNotification) {
        guard let keyboardSize = (notification.userInfo?[UIKeyboardFrameBeginUserInfoKey] as? NSValue)?.cgRectValue else {
            return
        }
        self.tableView.contentInset = UIEdgeInsets(top: self.tableView.contentInset.top, left: 0, bottom: keyboardSize.height, right: 0)

        if self.currentTextField != nil {
            let activeTextFieldRect = self.currentTextField?.superview?.superview?.frame
            self.tableView.scrollRectToVisible(activeTextFieldRect!, animated:true)
        }
    }
    
    func keyboardWillHide(notification: NSNotification) {
        let contentInsets = UIEdgeInsets(top: self.tableView.contentInset.top, left: 0, bottom: 0, right: 0)
        self.tableView.contentInset = contentInsets
        self.currentTextField = nil
    }
    
    @IBAction func onPressCloseButton(_ sender: UIButton) {
        dismiss(animated: true, completion: nil)
    }
    
    @IBAction func onPressSendButton(_ sender: UIButton) {
        self.submitForm()
    }
}

extension NewProductViewController: UITextFieldDelegate {
    func textFieldShouldBeginEditing(_ textField: UITextField) -> Bool {
        currentTextField = textField
        return true
    }
    
    func textFieldDidEndEditing(_ textField: UITextField) {
        (textField as! SkyFloatingLabelTextField).errorMessage = (textField.text?.isEmpty)! ? "*" : ""
    }
    
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        if textField === self.titleTextField {
            categoryTextField.becomeFirstResponder()
        } else if textField === categoryTextField {
            priceTextField.becomeFirstResponder()
        } else if textField === priceTextField {
            descriptionTextField.becomeFirstResponder()
        } else {
            view.endEditing(true)
        }
        return true
    }
}

extension NewProductViewController: UITableViewDelegate, UITableViewDataSource {
    func tableViewExtensionDidLoad() {
        tableView.delegate = self
        tableView.dataSource = self
        tableView.separatorStyle = .none
        tableView.allowsSelection = false
        tableView.keyboardDismissMode = .interactive
        
        tableView.register(UINib(nibName: "FloatInputTableViewCell", bundle: nil), forCellReuseIdentifier: "cell")
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 4
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return indexPath.row == Row.description ? 120 : 75
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "cell", for: indexPath) as! FloatInputTableViewCell
        cell.inputTextField.delegate = self
        
        switch indexPath.row {
        case Row.title:
            cell.inputTextField.placeholder = "Title".localize()
            cell.inputTextField.keyboardType = .asciiCapable
            titleTextField = cell.inputTextField
        case Row.category:
            cell.inputTextField.placeholder = "Category".localize()
            cell.inputTextField.keyboardType = .asciiCapable
            categoryTextField = cell.inputTextField
        case Row.price:
            cell.inputTextField.placeholder = "Daily price".localize()
            cell.inputTextField.keyboardType = .asciiCapable
            priceTextField = cell.inputTextField
        case Row.description:
            cell.inputTextField.placeholder = "Description".localize()
            cell.inputTextField.keyboardType = .asciiCapable
            descriptionTextField = cell.inputTextField
        default:
            return cell
        }
        
        return cell
    }
}

extension NewProductViewController : UICollectionViewDelegate, UICollectionViewDataSource, UICollectionViewDelegateFlowLayout, PhotoCollectionViewCellDelegate {
    
    func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        let cell = collectionView.dequeueReusableCell(
            withReuseIdentifier: "PhotosCollectionViewCell",
            for: indexPath
            ) as! PhotosCollectionViewCell
        
        cell.delegate = self
        
        if self.images.indices.contains(indexPath.row) {
            cell.setButtonImage(image: self.images[indexPath.row], tag: indexPath.row)
        } else {
            cell.setButton(tag: indexPath.row)
        }
        
        return cell
    }
    
    
    func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        return 4
    }
    
    func collectionView(_ collectionView: UICollectionView, layout collectionViewLayout: UICollectionViewLayout, sizeForItemAt indexPath: IndexPath) -> CGSize {
        
        let padding = 32.0
        let collectionViewSize = Double(collectionView.frame.size.width) - padding
        
        let width = CGFloat(collectionViewSize.divided(by: 4))
        let height = width
        return CGSize(width: width, height: height)
    }
    
    func onPressEmptyPhoto(sender: UIButton) {
        self.selectedPhotoButton = sender
        
        let actionSheetController: UIAlertController = UIAlertController(
            title: "Subir foto",
            message: "¡Una buena foto es un éxito asegurado!",
            preferredStyle: .actionSheet
        )
        
        let takePictureAction: UIAlertAction = UIAlertAction(title: "Tomar foto", style: .default) { action -> Void in
            self.presentPhotoPickerAction(UIImagePickerControllerSourceType.camera)
        }
        
        let choosePictureAction: UIAlertAction = UIAlertAction(title: "Elige una de tu álbum", style: .default) { action -> Void in
            self.presentPhotoPickerAction(UIImagePickerControllerSourceType.photoLibrary)
        }
        
        actionSheetController.addAction(UIAlertAction(title: "Cancelar", style: .cancel))
        actionSheetController.addAction(takePictureAction)
        actionSheetController.addAction(choosePictureAction)
        
        present(actionSheetController, animated: true, completion: nil)
    }
    
    func onPressFilledPhoto(sender: UIButton) {
        self.selectedPhotoButton = sender
        
        let actionSheetController: UIAlertController = UIAlertController(
            title: "Quitar foto",
            message: "¿Estás seguro de querer eliminar la foto?",
            preferredStyle: .actionSheet
        )
        
        let deletePhotoAction: UIAlertAction = UIAlertAction(title: "Sí, ¡fuera foto!", style: .default) { action -> Void in
            self.images.remove(at: sender.tag)
            self.collectionView.reloadData()
        }
        
        actionSheetController.addAction(UIAlertAction(title: "Cancelar", style: .cancel))
        actionSheetController.addAction(deletePhotoAction)
        
        present(actionSheetController, animated: true, completion: nil)
    }
}

extension NewProductViewController: UIImagePickerControllerDelegate {
    func uiImagePickerExtensionDidLoad() {
        picker.delegate = self
    }
    
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [String : Any]) {
        let chosenImage = info[UIImagePickerControllerOriginalImage] as! UIImage
        images.append(chosenImage)
        collectionView.reloadData()
        dismiss(animated: true, completion: nil)
    }
    
    func imagePickerControllerDidCancel(_ picker: UIImagePickerController) {
        dismiss(animated: true, completion: nil)
    }
    
    
    func presentPhotoPickerAction(_ type: UIImagePickerControllerSourceType) {
        self.picker.allowsEditing = false
        self.picker.sourceType = type
        self.present(self.picker, animated: true, completion: nil)
    }
}

extension NewProductViewController {
    func submitForm() -> Void {
        var error: Bool = false
        
        if (titleTextField.text?.isEmpty)! {
            error = true
            titleTextField.errorMessage = "*"
        }
        
        if (categoryTextField.text?.isEmpty)! {
            error = true
            categoryTextField.errorMessage = "*"
        }
        
        if (priceTextField.text?.isEmpty)! {
            error = true
            priceTextField.errorMessage = "*"
        }
        
        if (descriptionTextField.text?.isEmpty)! {
            error = true
            descriptionTextField.errorMessage = "*"
        }
        
        if error || images.isEmpty {
            return
        }
        
        let product = Product(
            title: titleTextField.text!,
            description: descriptionTextField.text!,
            category: categoryTextField.text!,
            price: Double(priceTextField.text!.replacingOccurrences(of: ",", with: "."))!,
            images: self.images
        )
        
        ProductNetwork.postProduct(product: product) { (product, error) in
            if product != nil {
                self.dismiss(animated: true, completion: nil)
            } else {
                print("ERROR")
            }
        }
    }
}
