//
//  NewReviewViewController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 21/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit
import Cosmos

class NewReviewViewController: UIViewController {
    @IBOutlet weak var titleLabel: UILabel!
    @IBOutlet weak var ratingView: CosmosView!
    @IBOutlet weak var textLabel: UILabel!
    @IBOutlet weak var textView: UITextView!
    @IBOutlet weak var buttonAction: ActionButton!

    let book: Book
    
    init(book: Book) {
        self.book = book
        super.init(nibName: "NewReviewViewController", bundle: nil)
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }

    override func viewDidLoad() {
        super.viewDidLoad()
        titleLabel.text = "Your opinion is important".localize()
        textLabel.text = "Write a comment".localize()
        textView.layer.borderWidth = 1
        textView.layer.borderColor = UIColor.gray.cgColor
        textView.returnKeyType = .done
        textView.delegate = self
        buttonAction.setTitle("Send".localize(), for: .normal)
    }
    
    @IBAction func onTapActionButton(_ sender: Any) {
        ProductNetwork.get(status: "published", productId: book.product) { (product, error) in
            // TODO: check errors
            if let product = product {
                let review = Review(
                    user: UserNetwork.currentUser(),
                    book: self.book,
                    product: product,
                    rating: self.ratingView.rating,
                    comment: self.textView.text
                )
                
                ReviewNetwork.create(review: review) { (error) in
                    // TODO: Check errors
                    self.navigationController?.popToRootViewController(animated: true)
                }
            }
        }
    }
}

extension NewReviewViewController: UITextViewDelegate {
    func textView(_ textView: UITextView, shouldChangeTextIn range: NSRange, replacementText text: String) -> Bool {
        if text == "\n" {
            textView.endEditing(true)
        }
        
        return true
    }
}
