//
//  PhotosCollectionViewCell.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 18/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit

protocol PhotoCollectionViewCellDelegate {
    func onPressEmptyPhoto(sender: UIButton)
    
    func onPressFilledPhoto(sender: UIButton)
}

class PhotosCollectionViewCell: UICollectionViewCell {
    
    @IBOutlet weak var photoButton: UIButton!
    
    let placeholder = UIImage(named: "ic_photo")!
    
    var delegate: PhotoCollectionViewCellDelegate?
    
    override func awakeFromNib() {
        super.awakeFromNib()
        
        photoButton.addTarget(self, action: #selector(onPressPhoto), for: .touchUpInside)
    }
    
    private func setButtonImage(image: UIImage) {
        photoButton.setImage(image, for: .normal)
    }
    
    func setButtonImage(image: UIImage, tag: Int) {
        setButtonImage(image: image)
        photoButton.tag = tag
    }
    
    func setButton(tag: Int) {
        setButtonImage(image: placeholder)
        photoButton.tag = tag
    }
    
    func onPressPhoto(sender: UIButton!) {
        guard delegate != nil else {
            return
        }
        
        if (sender.imageView?.image?.isEqual(placeholder))! {
            delegate?.onPressEmptyPhoto(sender: sender)
        } else {
            delegate?.onPressFilledPhoto(sender: sender)
        }
    }
    
    
}
