//
//  Product.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 13/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import Foundation
import ObjectMapper

class Product: Mappable {
    var id: String              = ""
    var name: String            = ""
    var description: String     = ""
    var category: String        = ""
    var price: Double           = 0
    var scoreAverage: Double    = 0
    var images: [String]        = []
    var uIImages: [UIImage]     = []
    var user: String            = ""
    
    var userImage: String?
    var userInstance: User?
    
    public required init?(map: Map) {
    }
    
    func mapping(map: Map) {
        self.id             <- map["id"]
        self.name           <- map["name"]
        self.description    <- map["description"]
        self.category       <- map["category"]
        self.price          <- map["price"]
        self.scoreAverage   <- map["scoreAverage"]
        self.images         <- map["images"]
        self.user           <- map["user"]
    }
    
    static func mapDictionary(json: [String : [String : Any]]) -> [Product] {
        let dictionary = Mapper<Product>().mapDictionary(JSON: json)
        
        var products: [Product] = []
        for product in dictionary!.values {
            products.append(product)
        }
        
        return products
    }
    
    init(title: String, description: String, category: String, price: Double, images: [UIImage]) {
        self.id             = UUID().uuidString
        self.name           = title
        self.description    = description
        self.category       = category
        self.price          = price
        self.uIImages       = images
    }
    
    func addImage(imageUrl: String) -> Void {
        self.images.append(imageUrl)
    }
    
    func user(_ completion: @escaping (_ : User?, _ : Error?) -> Void) -> Void {
        if self.userInstance != nil {
             completion(self.userInstance, nil)
        }
        
        UserNetwork.getUser(userId: self.user) { (user, error) in
            if let user = user {
                self.userInstance = user
                completion(self.userInstance, error)
            } else {
                completion(nil, error)
            }
        }
    }
    
    func getPrice(forDays count: Int) -> Double {
        return price.multiplied(by: Double(count))
    }
    
    func reviews(_ completion: @escaping (_ : [Review], _ : Error? ) -> Void) {
        ReviewNetwork.getReviews(product: self) { (reviews, error) in
            completion(reviews, error)
        }
    }
}
