//
//  ProductCollectionViewCell.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 13/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit
import Cosmos
import Kingfisher

class ProductCollectionViewCell: UICollectionViewCell {

    @IBOutlet weak var nameLabel: UILabel!
    @IBOutlet weak var priceLabel: UILabel!
    @IBOutlet weak var categoryLabel: UILabel!
    @IBOutlet weak var ratingView: CosmosView!
    @IBOutlet weak var imageView: UIImageView!
    @IBOutlet weak var avatarImageView: UIImageView!
    
    func loadData(_ product: Product) {
        nameLabel.text = product.name
        priceLabel.text = "@ / day".localize(wildcard: String(product.price))
        categoryLabel.text = product.category
        ratingView.rating = product.scoreAverage
        
        let avatarWidth = avatarImageView.frame.width
        avatarImageView.layer.cornerRadius = avatarWidth / 2
        avatarImageView.layer.masksToBounds = true
        
        
        let url = URL(string: (product.images[0]))
        imageView.kf.indicatorType = .activity
        imageView.kf.setImage(with: url)
        
        priceLabel.textColor = UIColor.blue
        
        UserNetwork.getUser(userId: product.user) { (user, error) in
            if let user = user {
                let processor = RoundCornerImageProcessor(cornerRadius: avatarWidth / 2)
                let url = URL(string: user.avatar)
                self.avatarImageView.kf.setImage(with: url, options: [.processor(processor)])
            }
        }
    }
}
