//
//  ProductDetailViewController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 12/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit
import ImageSlideshow
import Kingfisher
import MapKit

class ProductDetailViewController: MainViewController {    
    @IBOutlet weak var tableView: UITableView!
    @IBOutlet weak var footerView: UIView!
    
    var product: Product
    var reviews: [Review] = [] {
        didSet {
            self.tableView.reloadSections([1], with: .automatic)
        }
    }
    
    var mapView: MKMapView!
    
    init(product: Product) {
        self.product = product
        super.init(nibName: "ProductDetailViewController", bundle: nil)
    }
    
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func viewWillAppear(_ animated: Bool) {
        navigationController?.navigationBar.tintColor = UIColor.white
        navigationItem.backBarButtonItem = UIBarButtonItem(title: "", style: .plain, target: nil, action: nil)
        loadUserData()
    }
    
    override func viewDidLoad() {
        ReviewNetwork.getReviews(product: product) { (reviews, error) in
            self.reviews = reviews
        }
        
        tableViewDidLoad()
        automaticallyAdjustsScrollViewInsets = false
        
        let footer = Bundle.main.loadNibNamed("ProductBottomView", owner: self)?.first as! ProductBottomView
        footer.frame = CGRect(
            x: 0,
            y: 0,
            width: view.frame.width,
            height: 60
        )
        footer.loadView(product: product)
        footer.bookButton.addTarget(self, action: #selector(onTapBookButton), for: .primaryActionTriggered)
        footerView.addSubview(footer)
    }
    
    func onTapBookButton() {
        let vc = NewBookViewController(product: product)
        navigationController?.pushViewController(vc, animated: true)
    }
    
    func loadUserData() {
        let avatarWidth = UIScreen.main.bounds.width / 4
        let y = (UIScreen.main.bounds.height / 4) - (avatarWidth/2) 
        let x = UIScreen.main.bounds.width - 16 - avatarWidth
        
        let avatarImageView = UIImageView(frame: CGRect(
            x: x,
            y: y,
            width: avatarWidth,
            height: avatarWidth
        ))
        avatarImageView.clipsToBounds = true
        avatarImageView.layer.cornerRadius = avatarWidth / 2
        avatarImageView.layer.masksToBounds = true
        let processor = RoundCornerImageProcessor(cornerRadius: avatarWidth)
        
        product.user() { (user, error) in
            if let user = user {
                let url = URL(string: user.avatar)
                avatarImageView.kf.setImage(with: url, options: [.processor(processor)])
                self.tableView.addSubview(avatarImageView)
            }
        }
    }
}

extension ProductDetailViewController: UITableViewDataSource, UITableViewDelegate {
    struct Row {
        static let photos = 0
        static let info = 1
        static let reviews = 2
    }
    
    func tableViewDidLoad() {
        tableView.delegate = self
        tableView.dataSource = self
        tableView.separatorStyle = .none
        tableView.estimatedRowHeight = 150
        tableView.rowHeight = UITableViewAutomaticDimension
        
        tableView.register(ImageSlideTableViewCell.self, forCellReuseIdentifier: "imagesCell")
        tableView.register(UINib(nibName:"ProductInfoTableViewCell", bundle: nil), forCellReuseIdentifier: "infoCell")
        tableView.register(UINib(nibName:"ReviewTableViewCell", bundle: nil), forCellReuseIdentifier: "reviewCell")
        
    }
    
    func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        return section == 1 && reviews.count > 0 ? "Reviews".localize() : ""
    }
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 2
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return section == 0 ? 2 : reviews.count
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        if indexPath.section == 1 {
            return 90
        }
        
        switch indexPath.row {
        case Row.photos:
            return UIScreen.main.bounds.height / 4
        case Row.info:
            return 240
        default:
            return 150
        }
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        if indexPath.section == 1 {
            let cell = tableView.dequeueReusableCell(withIdentifier: "reviewCell", for: indexPath) as! ReviewTableViewCell
            cell.selectionStyle = .none
            cell.fillViewData(review: reviews[indexPath.row])
            return cell

        }
        
        switch indexPath.row {
        case Row.photos:
            let cell = tableView.dequeueReusableCell(withIdentifier: "imagesCell", for: indexPath) as! ImageSlideTableViewCell
            cell.slideshow.frame = CGRect(x: 0, y: 0, width: tableView.frame.width, height: UIScreen.main.bounds.height / 4)
            cell.loadImages(urls: product.images)
            cell.selectionStyle = .none
            return cell
            
        case Row.info:
            let cell = tableView.dequeueReusableCell(withIdentifier: "infoCell", for: indexPath) as! ProductInfoTableViewCell
            cell.selectionStyle = .none
            cell.loadData(product: product)
            self.mapView = cell.mapView
            return cell
            
        default:
            return UITableViewCell()
        }
    }
}

