//
//  ProductInfoTableViewCell.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 14/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit
import MapKit

class ProductInfoTableViewCell: UITableViewCell {

    @IBOutlet weak var titleLabel: UILabel!
    @IBOutlet weak var categoryLabel: UILabel!
    @IBOutlet weak var descriptionLabel: UILabel!
    @IBOutlet weak var mapView: MKMapView!
    
    override func layoutSubviews() {
        self.mapView.isZoomEnabled = false
        self.mapView.isScrollEnabled = false
        self.mapView.isUserInteractionEnabled = false
    }
    
    func loadData(product: Product) {
        titleLabel.text = product.name
        titleLabel.frame = CGRect(
            x: 0,
            y: 0,
            width: titleLabel.frame.width,
            height: UILabel.heightForView(text: titleLabel.text!, font: titleLabel.font, width: 100)
        )
        categoryLabel.text = product.category
        descriptionLabel.text = product.description
        descriptionLabel.frame = CGRect(
            x: 0,
            y: 0,
            width: descriptionLabel.frame.width,
            height: UILabel.heightForView(text: descriptionLabel.text!, font: descriptionLabel.font, width: 100)
        )
        
        product.user() { (user, error) in
            if let user = user {
                let latitude = user.latitude == 0 ? User.defaultLatitude : user.latitude
                let longitude = user.longitude == 0 ? User.defaultLongitude : user.longitude
                let distance: CLLocationDistance = user.latitude == 0 ? 30000 : 500
                
                let location = CLLocation(latitude: latitude, longitude: longitude)
                let coordinateRegion = MKCoordinateRegionMakeWithDistance(location.coordinate, distance, distance)
                self.mapView.setRegion(coordinateRegion, animated: false)
            }
        }
    }
}
