//
//  ProductListViewController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 12/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit

class ProductListViewController: MainViewController {
    @IBOutlet weak var collectionView: UICollectionView!
    @IBOutlet weak var headerView: UIView!
    
    var products: [Product] = []
    var refreshControl: UIRefreshControl!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        collectionViewDidLoad()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        navigationController?.hide()
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        navigationController?.setTranslucentBar()
        navigationItem.backBarButtonItem = UIBarButtonItem(title: "", style: .plain, target: nil, action: nil)
    }
}

extension ProductListViewController: UICollectionViewDelegate, UICollectionViewDataSource, UICollectionViewDelegateFlowLayout {
    func collectionViewDidLoad() {
        collectionView.delegate = self
        collectionView.dataSource = self
        
        refreshControl = UIRefreshControl()
        refreshControl.addTarget(self, action: #selector(refreshCollection), for: .valueChanged)
        collectionView.refreshControl = refreshControl
        collectionView.register(UINib(nibName: "ProductCollectionViewCell", bundle: nil), forCellWithReuseIdentifier: "cell")
        collectionView.allowsSelection = true
        
        refreshCollection()
    }
    
    func refreshCollection() {
        refreshControl.beginRefreshing()
        ProductNetwork.getProducts() { (products, error) in
            self.refreshControl.endRefreshing()
            self.products = products
            self.collectionView.reloadData()
        }
    }
    
    
    func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        return products.count
    }
    
    func collectionView(_ collectionView: UICollectionView, layout collectionViewLayout: UICollectionViewLayout, sizeForItemAt indexPath: IndexPath) -> CGSize {
        let padding = 8.0
        let collectionViewSize = Double(collectionView.frame.width) - padding
        
        let width = CGFloat(collectionViewSize.divided(by: 2))
        let height = width.divided(by: CGFloat(0.67))
        return CGSize(width: width, height: height)
    }
    
    func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        let cell: ProductCollectionViewCell = collectionView.dequeueReusableCell(withReuseIdentifier: "cell", for: indexPath) as! ProductCollectionViewCell
        
        cell.layer.borderWidth = 0.5
        cell.layer.borderColor = UIColor(rgb: 0xdcdcdc).cgColor
        cell.layer.cornerRadius = 10
        let product = self.products[indexPath.row]
        cell.loadData(product)
        
        return cell
        
    }
    
    func collectionView(_ collectionView: UICollectionView, didSelectItemAt indexPath: IndexPath) {
        let vc = ProductDetailViewController(product: self.products[indexPath.row])
        vc.hidesBottomBarWhenPushed = true
        self.navigationController?.pushViewController(vc, animated: true)
    }
}
