//
//  ProductNetwork.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 13/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import Foundation
import ObjectMapper
import Firebase

class ProductNetwork {
    
    static func get(status: String, productId: String, _ completion: @escaping (_ : Product?, _ : Error? ) -> Void) {
        let path = "/products/\(status)/\(productId)"
        
        FIRDatabase
            .database()
            .reference()
            .child(path)
            .observeSingleEvent(of: .value) { (snapshot: FIRDataSnapshot) in
                guard let json = snapshot.value as? [String: Any] else {
                    completion(nil, nil)
                    return
                }
                guard let product = Mapper<Product>().map(JSON: json) else {
                    completion(nil, nil)
                    return
                }
                
                completion(product, nil)
        }
    }
    
    static func getProducts(_ completion: @escaping (_ : [Product], _ : Error?) -> Void) {
        FIRDatabase
            .database()
            .reference()
            .child(Constant.Firebase.Snapshot.products)
            .observeSingleEvent(of: .value) { (snapshot: FIRDataSnapshot) in
                if let snapshots = snapshot.value as? [String : [String : Any]] {
                    let products = Product.mapDictionary(json: snapshots)
                    return completion(products, nil)
                }
                
                completion([], nil)
                
        }
    }
    
    static func postProduct(product: Product, _ completion: @escaping (_ : Product?, _ : Error?) -> Void) -> Void {
        let metaData = FIRStorageMetadata()
        metaData.contentType = "image/jpg"
        
        var totalImages = product.uIImages.count
        
        for (index, image) in product.uIImages.enumerated() {
            let photo = UIImageJPEGRepresentation(image, 0.8)
            
            let task = FIRStorage.storage(url:Constant.Firebase.storageUrl).reference()
                .child("products/\(product.id)/\(product.name)-\(index)-\(NSDate()).jpg")
                .put(photo!, metadata: metaData)
            
            task.observe(.success, handler: { snapshot in
                let url = snapshot.metadata?.downloadURL()?.absoluteString
                product.addImage(imageUrl: url!)
                
                if totalImages == 0 {
                    totalImages -= 1
                } else {
                    product.user = UserNetwork.currentUser().uid
                    FIRDatabase
                        .database()
                        .reference()
                        .child(Constant.Firebase.Snapshot.pendingProducts)
                        .child(product.id)
                        .setValue(product.toJSON())
                    
                    completion(product, nil)
                }
            })
        }
    }
}
