//
//  ProtectedViewController.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 13/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit

class ProtectedViewController: UIViewController {
    
    let viewController: UIViewController
    var subViewController: UIViewController?
    var isModal: Bool
    
    init(_ viewController: UIViewController, isModal: Bool = false) {
        self.viewController = viewController
        self.isModal = isModal
        super.init(nibName: nil, bundle: nil)
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        displayContentController()
        
        NotificationCenter.default.addObserver(
            self,
            selector: #selector(reloadContent),
            name: NSNotification.Name(rawValue: Constant.Event.login),
            object: nil
        )
        
        NotificationCenter.default.addObserver(
            self,
            selector: #selector(reloadContent),
            name: NSNotification.Name(rawValue: Constant.Event.logout),
            object: nil
        )
    }
    
    func reloadContent() {
        hideContentController()
        displayContentController()
    }
    
    func displayContentController() {
        subViewController = UserNetwork.isLogged()
            ? self.viewController
            : AnonymousProfileViewController(isModal: isModal)
        
        addChildViewController(subViewController!)
        subViewController?.view.frame = view.frame
        view.addSubview(subViewController!.view)
    }
    
    func hideContentController() {
        subViewController?.willMove(toParentViewController: nil)
        subViewController?.view.removeFromSuperview()
        subViewController?.removeFromParentViewController()
    }
}
