//
//  ReviewNetwork.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 21/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import Foundation
import FirebaseDatabase

class ReviewNetwork {
    static func create(review: Review, _ completion: @escaping (_ : Error?) -> Void) {
        let path = "/reviews/\(review.book)"
        
        UserNetwork.getUser(userId: review.user) { (user, error) in
            if let error = error {
                completion(error)
            }
            
            if let user = user {
                review.userName = user.name
                review.userImage = user.avatar

                FIRDatabase
                    .database()
                    .reference()
                    .child(path)
                    .childByAutoId()
                    .setValue(review.toJSON(), withCompletionBlock: { (error, snapshot) in
                        completion(error)
                    })
                
                completion(nil)
            }
        }
    }
    
    static func getReviews(product: Product, _ completion: @escaping (_ : [Review], _ : Error? ) -> Void) {
        let path = "/products/published/\(product.id)/reviews"
        
        FIRDatabase
            .database()
            .reference()
            .child(path)
            .observeSingleEvent(of: .value) { (snapshot: FIRDataSnapshot) in
                if let snapshots = snapshot.value as? [String : [String : Any]] {
                    let reviews = Review.mapDictionary(json: snapshots)
                    return completion(reviews, nil)
                }
                
                completion([], nil)
        }
    }
}
