//
//  RoomTableViewCell.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 15/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit
import Kingfisher

class RoomTableViewCell: UITableViewCell {

    @IBOutlet weak var photoView: UIImageView!
    @IBOutlet weak var titleLabel: UILabel!
    @IBOutlet weak var lastMessageLabel: UILabel!
    @IBOutlet weak var lastMessageDateLabel: UILabel!
    @IBOutlet weak var bookStatusLabel: UILabel!
    
    
    override func awakeFromNib() {
        super.awakeFromNib()
        
        photoView.layer.masksToBounds = true
        photoView.layer.cornerRadius = photoView.frame.width / 6
        selectionStyle = .none
    }
    
    func loadView(room: Room) -> Void {
        titleLabel.text = room.title
        lastMessageLabel.text = room.lastMessage
        photoView.kf.indicatorType = .activity
        
        let date = Date(timeIntervalSince1970: TimeInterval(room.timestamp))
        let dateFormatter = DateFormatter()
        dateFormatter.timeZone = TimeZone(identifier: "GMT")
        dateFormatter.locale = NSLocale.current
        dateFormatter.dateFormat = "dd-MM-yyyy HH:mm"
        lastMessageDateLabel.text = dateFormatter.string(from: date)
        
        BookNetwork.get(status: room.status, bookId: room.book) { (book, error) in
            if let book = book {
                self.bookStatusLabel.text = book.statusLabel()
                
                ProductNetwork.get(status: "published", productId: book.product, { (product, error) in
                    let processor = RoundCornerImageProcessor(cornerRadius: self.photoView.frame.width / 6)
                    if let product = product {
                        if !product.images.isEmpty {
                            let url = URL(string: product.images[0])
                            self.photoView.kf.setImage(with: url, options: [.processor(processor)])
                        }
                    }
                })
            }
            
        }
    }
}
