//
//  TimeLineRowView.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 20/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import UIKit

//@IBDesignable
class TimeLineRowView: UIView {
    
    @IBOutlet weak var imageView: UIButton!
    @IBOutlet weak var titleLabel: UILabel!
    @IBOutlet weak var subTitleLabel: UILabel!
    @IBOutlet weak var topLine: UIView!
    @IBOutlet weak var bottomLine: UIView!
    
    private var proxyView: TimeLineRowView?
    
    @IBInspectable var image: UIImage = UIImage() {
        didSet {
            let size = image.size
            let rect = CGRect(x: 0, y: 0, width: size.width, height: size.height)
            UIGraphicsBeginImageContextWithOptions(size, false, 0.0)
            let path = UIBezierPath(rect: rect)
            path.addClip()
            image.draw(in: rect)
            
            let currentImage = UIGraphicsGetImageFromCurrentImageContext()
            UIGraphicsEndImageContext()
            self.proxyView!.imageView.setImage(currentImage, for: .normal)
        }
    }
    
    @IBInspectable var title: String = "" {
        didSet {
            proxyView?.titleLabel.text = title
        }
    }
    
    @IBInspectable var subTitle: String = "" {
        didSet {
            proxyView?.subTitleLabel.text = subTitle
        }
    }
    
    @IBInspectable var isFirstItem: Bool = false {
        didSet {
            proxyView?.topLine.isHidden = isFirstItem
        }
    }
    
    @IBInspectable var isLastItem: Bool = false {
        didSet {
            proxyView?.bottomLine.isHidden = isLastItem
        }
    }
    
    @IBInspectable var inactiveColor: UIColor = UIColor.gray {
        didSet {
            proxyView?.inactiveColor = inactiveColor
        }
    }
    
    @IBInspectable var activeColor: UIColor = UIColor.blue {
        didSet {
            proxyView?.activeColor = activeColor
        }
    }
    
    @IBInspectable var sectionsActivated: Int = 0 {
        didSet {
            switch sectionsActivated {
            case 1:
                proxyView?.topLine.backgroundColor      = activeColor
                proxyView?.bottomLine.backgroundColor   = inactiveColor
                proxyView?.imageView.tintColor          = activeColor
            case 2:
                proxyView?.topLine.backgroundColor      = activeColor
                proxyView?.bottomLine.backgroundColor   = activeColor
                proxyView?.imageView.tintColor          = activeColor
            default:
                proxyView?.topLine.backgroundColor      = inactiveColor
                proxyView?.bottomLine.backgroundColor   = inactiveColor
                proxyView?.imageView.tintColor          = inactiveColor
            }
        }
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        let view = loadNib()
        view.frame = self.bounds
        view.autoresizingMask = [.flexibleWidth, .flexibleHeight]
        proxyView = view
        self.addSubview(proxyView!)
    }
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
        self.proxyView = self
    }
    
    override func awakeAfter(using aDecoder: NSCoder) -> Any? {
        guard subviews.count == 0 else {
            return self
        }

        let view = loadNib()
        view.translatesAutoresizingMaskIntoConstraints = false
        let contraints = self.constraints
        self.removeConstraints(contraints)
        view.addConstraints(contraints)
        proxyView = view
        
        return view
    }
    
    private func loadNib() -> TimeLineRowView {
        let bundle = Bundle(for: type(of: self))
        return bundle.loadNibNamed("TimeLineRowView", owner: nil, options: nil)?[0] as! TimeLineRowView
    }
}
