//
//  UIColor.swift
//  migamy
//
//  Created by Daniel Funes Garcia-Penche on 12/05/2017.
//  Copyright © 2017 Daniel Funes Garcia-Penche. All rights reserved.
//

import Foundation
import UIKit

extension UIColor {
    convenience init(red: Int, green: Int, blue: Int) {
        assert(red >= 0 && red <= 255, "Invalid red component")
        assert(green >= 0 && green <= 255, "Invalid green component")
        assert(blue >= 0 && blue <= 255, "Invalid blue component")
        
        self.init(red: CGFloat(red) / 255.0, green: CGFloat(green) / 255.0, blue: CGFloat(blue) / 255.0, alpha: 1.0)
    }
    
    convenience init(rgb: Int) {
        self.init(
            red: (rgb >> 16) & 0xFF,
            green: (rgb >> 8) & 0xFF,
            blue: rgb & 0xFF
        )
    }
    
    static var blue: UIColor {
        return UIColor(rgb: 0x0067B3)
    }
    
    static var orange: UIColor {
        return UIColor(rgb: 0xFF9500)
    }
    
    static var primaryText: UIColor {
        return UIColor(rgb: 0x4A4A4A)
    }
    
    static var secondaryText: UIColor {
        return UIColor(rgb: 0xD3D1D1)
    }
    
    static var background: UIColor {
        return UIColor(rgb: 0xFBFBFB)
    }
}
